export interface GuruCardRaw {
    content: string;
    id: string;
    lastModified: string;
    owner: {
        status: string;
        email: string;
        firstName: string;
        lastName: string;
        profilePicUrl: string;
    };
    slug: string;
    collection: {
        name: string;
        id: string;
        color: string;
        collectionType: string;
        publicCardsEnabled: boolean;
        roiEnabled: boolean;
    };
    dateCreated: string;
    verifiers: Array<{
        type: string;
        user: {
            status: string;
            email: string;
            firstName: string;
            lastName: string;
            profilePicUrl: string;
        };
        id: string;
    }>;
    verificationInterval: number;
    lastVerified: string;
    lastVerifiedBy: {
        status: string;
        email: string;
        firstName: string;
        lastName: string;
        profilePicUrl: string;
    };
    lastModifiedBy: {
        status: string;
        email: string;
        firstName: string;
        lastName: string;
        profilePicUrl: string;
    };
    htmlContent: boolean;
    shareStatus: string;
    boards: Array<{
        id: string;
        title: string;
        slug: string;
        items: any[];
        numberOfFacts: number;
    }>;
    preferredPhrase: string;
    originalOwner: {
        status: string;
        email: string;
        firstName: string;
        lastName: string;
        profilePicUrl: string;
    };
    verificationState: string;
    verificationType: string;
    cardType: string;
    nextVerificationDate: string;
    cardInfo: {
        analytics: {
            unverifiedViews: number;
            boards: number;
            views: number;
            copies: number;
            unverifiedCopies: number;
            favorites: number;
        };
    };
}
export interface GuruCard {
    [key: string]: any;
    id: string;
    title: string;
    owner: string;
    firstName: string;
    lastName: string;
    verifier: string;
    collection: string;
    boards: string[];
    content: string;
    verificationDate: string;
    verificationState: string;
    verificationInterval: number;
    link: string;
}
export interface GuruConfig {
    email: string;
    token: string;
}
export interface GuruStatusResponse {
    status: string;
    message: string;
}
export declare class Guru {
    private readonly email;
    private readonly token;
    private readonly httpConfig;
    constructor(_config: GuruConfig);
    private _request;
    _convertCardModel(cardRaw: GuruCardRaw): GuruCard;
    authenticated(): Promise<{
        authenticated: boolean;
        message: string;
    }>;
    getAllCardsRaw(): Promise<GuruCardRaw[]>;
    getAllCards(): Promise<GuruCard[]>;
    getCardsByTitle(cardTitle: string): Promise<GuruCard[]>;
    verifyCardsByTitle(cardTitle: string): Promise<GuruStatusResponse>;
    getAllExpiredCardsRaw(): Promise<GuruCardRaw[]>;
    updateCardRaw(cardRaw: GuruCardRaw): Promise<GuruCardRaw>;
    getAllCollections(): Promise<any>;
    createImpersonationToken(userEmail: string): Promise<string>;
}
